# ![](https://i.ibb.co/JKWYP5X/Group-1.png)
### Easly manage configurations with tiny library

This a a work in progress. We will be updating it soon with more information and documentation on how to use and extend **Confite**

## Installing confite

```bash
pip install confite
```
